<?php
/**
 * AdminMenuPanorama
 * Version    : 0.1
 * Author     : Green Sheep
 * Created    : November 5, 2017
 * Modified   :
 * License    : GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */
namespace plugins\wpv;

class AdminMenuPanorama
{
    /**
     * パノラマ画像用のカスタムフィールド
     */
    public function __construct()
    {
        // メタボックスを追加するページタイプを指定
        $screens = ['post', 'page'];
        // フィルターフック
        $screens = apply_filters('wpv_add_meta_box', $screens);

        // メタボックスの追加
        foreach ($screens as $screen) {
            add_meta_box(
                'wp_panorama_view_meta_box',
                'パノラマ画像',
                array($this, 'addMetaBoxPanorama'),
                $screen,
                'normal',
                'low'
            );
        }

        // カスタムフィールド保存処理
        add_action('save_post', array($this, 'customSavePanoramaView'));
    }

    /**
     * パノラマ画像用のカスタムフィールドを表示
     */
    public function addMetaBoxPanorama()
    {
        global $post;

        for ($i = 1; $i <= Cmn::imageCount(); $i++) {
            // データ取得
            $wpv_image = wp_strip_all_tags(get_post_meta($post->ID, '_wpv_image' . $i, true));
            $wpv_image_name = wp_strip_all_tags(get_post_meta($post->ID, '_wpv_image_name' . $i, true));

            // 検証
            $wpv_image = (preg_match('/\A[0-9]+\z/', $wpv_image)) ? $wpv_image : '';
            $wpv_image_name = mb_substr($wpv_image_name, 0, 5);
            ?>
            <input type="hidden" name="wpv_image_nonce" id="wpv_image_nonce" value="<?php echo wp_create_nonce(plugin_basename(__FILE__)); ?>" />
            <div id="media-_wpv_image<?php echo $i; ?>" class="media-wpv-image">
            <?php if ($wpv_image !== '') {
                echo wp_get_attachment_image($wpv_image, 'thumbnail');
            } ?>
            </div>
            <div class="wpv-panorama-image-side">
                <input type="button" name="media-select-_wpv_image<?php echo $i; ?>" class="button" value="画像を選択">
                <input type="button" name="media-clear-_wpv_image<?php echo $i; ?>" class="button" value="クリア">
                <input name="_wpv_image<?php echo $i; ?>" type="hidden" value="<?php echo $wpv_image; ?>">
                <label>画像タイプ<?php echo $i; ?><input type="text" id="wpv_image_name<?php echo $i; ?>" class="-text" name="_wpv_image_name<?php echo $i; ?>" value="<?php echo $wpv_image_name; ?>">※5文字まで</label>
            </div>
            <?php
            if ($i != Cmn::imageCount()) {
                echo '<hr>';
            }
        }
    }

    /**
     * パノラマ画像用のカスタムフィールドの保存
     *
     * @param string post_id
     * @return string post_id
     */
    public function customSavePanoramaView($post_id)
    {
        // nonceのチェック
        if (!isset($_POST['wpv_image_nonce'])) {
            return $post_id;
        }
        if (!wp_verify_nonce($_POST['wpv_image_nonce'], plugin_basename(__FILE__))) {
            return $post_id;
        }
        // パーミッションチェック
        if (!current_user_can('edit_page', $post_id)) {
            return $post_id;
        }

        for ($i = 1; $i <= Cmn::imageCount(); $i++) {
            // データの保存
            $wpv_image = isset($_POST['_wpv_image' . $i]) ? $_POST['_wpv_image' . $i] : '';
            $wpv_image_name = isset($_POST['_wpv_image_name' . $i]) ? $_POST['_wpv_image_name' . $i] : '';

            // 検証
            $wpv_image = (preg_match('/\A[0-9]+\z/', $wpv_image)) ? $wpv_image : '';
            $wpv_image_name = mb_substr($wpv_image_name, 0, 5);

            if ($wpv_image === '') {
                $wpv_image_name = '';
            }

            // 更新
            update_post_meta($post_id, '_wpv_image' . $i, (int)$wpv_image);
            update_post_meta($post_id, '_wpv_image_name' . $i, $wpv_image_name);
        }
    }
}
