<?php
/**
 * InitPlugin
 * Version    : 0.1
 * Author     : Green Sheep
 * Created    : November 2, 2017
 * Modified   :
 * License    : GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */
namespace plugins\wpv;

class InitPlugin
{
    /**
     * 管理画面・フロントにて独自のcssやjavascriptを読み込ませる
     */
    public function executeEnqueueScripts()
    {
        add_action('wp_enqueue_scripts', array($this, 'wpScript'));
        add_action('admin_enqueue_scripts', array($this, 'adminScript'));
    }

    /**
     * フロント画面にて独自のjavascriptとcssを読み込ませる
     */
    public function wpScript()
    {

        // js
        wp_enqueue_script(
            Cmn::PREFIX . 'three',
            Cmn::pluginUrlPath() . 'js/three.min.js',
            array(),
            false,
            true
        );
        wp_enqueue_script(
            Cmn::PREFIX . 'DeviceOrientationControls',
            Cmn::pluginUrlPath() . 'js/DeviceOrientationControls.min.js',
            array(),
            false,
            true
        );
        wp_enqueue_script(
            Cmn::PREFIX . 'OrbitControls',
            Cmn::pluginUrlPath() . 'js/OrbitControls.min.js',
            array(),
            false,
            true
        );
        wp_enqueue_script(
            Cmn::PREFIX . 'fullscreen-ios',
            Cmn::pluginUrlPath() . 'js/fullscreen-ios.min.js',
            array('jquery'),
            false,
            true
        );
        wp_enqueue_script(
            Cmn::PREFIX . 'common',
            Cmn::pluginUrlPath() . 'js/common.min.js',
            array('jquery'),
            false,
            true
        );

        // css
        wp_enqueue_style(
            Cmn::PREFIX . 'front-css',
            Cmn::pluginUrlPath() . 'css/common.min.css',
            false,
            'all'
        );
    }

    /**
     * 管理画面にて独自のjavascriptとcssを読み込ませる
     */
    public function adminScript()
    {
        global $hook_suffix;

        if (strpos($hook_suffix, 'post.php') !== false || strpos($hook_suffix, 'post-new.php') !== false) {
            // js
            wp_enqueue_media();
            wp_enqueue_script(
                Cmn::PREFIX . 'media-uploader-js',
                Cmn::pluginUrlPath() . 'js/media-uploader.min.js',
                array('jquery'),
                '',
                true
            );
            wp_enqueue_script(
                Cmn::PREFIX . 'admin-shortcode-button-js',
                Cmn::pluginUrlPath() . 'js/shortcodeButton.min.js',
                array('jquery'),
                false,
                true
            );

            // css
            wp_enqueue_style(
                Cmn::PREFIX . 'admin-css',
                Cmn::pluginUrlPath() . 'css/admin.min.css',
                array(),
                false,
                'all'
            );
        }
    }

    /**
     * プラグイン専用のオプションデータ削除
     */
    public function deleteWpPanoramaViewOptions()
    {
        if (DAO::getOption('delete_flg') !== '1') {
            return;
        }

        // プラグインに関連するオプション名を取得
        $options_name = DAO::getOptionsName();

        // 全オプションを削除
        foreach ($options_name as $option_name) {
            delete_option($option_name['option_name']);
        }
    }
}
