<?php
/**
 * FrontMenuPanorama
 * Version    : 0.1
 * Author     : Green Sheep
 * Created    : November 6, 2017
 * Modified   :
 * License    : GPLv2 or later
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */
namespace plugins\wpv;

class FrontMenuPanorama
{
    /** 投稿ID */
    private $post_id;

    /** 画像URL */
    private $src;

    /**
     * パノラマ画像用のカスタムフィールド
     */
    public function __construct()
    {
        // ショートコードの登録
        add_shortcode('wp-panorama-view', array($this, '\plugins\wpv\FrontMenuPanorama::panoramaShortcodeFunc'));
    }

    public function panoramaShortcodeFunc($atts)
    {
        // ショートコードの引数を抽出してセット
        $this->setShortcodeArgument($atts);

        // パノラマ画像表示の条件チェック
        if (!$this->checkCondition()) {
            // 表示条件に合わない場合は表示しない
            return false;
        }

        $return  = '';

        if ($this->src !== '') {
            // パノラマ画像単体の表示
            $return .= $this->getPanoramaSingle();
        } else {
            // サムネイル付きのパノラマ画像セットを表示
            $return .= $this->getPanoramaSet();
        }

        // 管理画面で設定したパノラマ画像表示に関する設定値を取得する
        $return .= $this->getSettingValueScript();

        return $return;
    }

    /**
     * パノラマ画像単体の表示
     *
     * @return string パノラマ画像表示のhtml
     */
    private function getPanoramaSingle()
    {
        $return  = '';

        $return .= '<div class="panorama-wrap">';
        $return .=     '<div class="panorama-stage-wrap">';
        $return .=         '<div class="panorama-stage"></div>';
        $return .=         '<div class="panorama-control pause"></div>';
        $return .=         '<div class="panorama-fullscreen" title="最大化">';
        $return .=           '<div class="fullscreen-child1"></div>';
        $return .=           '<div class="fullscreen-child2"></div>';
        $return .=           '<div class="fullscreen-child3"></div>';
        $return .=           '<div class="fullscreen-child4"></div>';
        $return .=         '</div>';
        $return .=         '<div class="panorama-gyro" title="ジャイロ">';
        $return .=           '<div class="gyro-child"></div>';
        $return .=         '</div>';
        $return .=         '<div class="sk-circle panorama-loading">';
        $return .=             '<div class="sk-circle1 sk-child"></div>';
        $return .=             '<div class="sk-circle2 sk-child"></div>';
        $return .=             '<div class="sk-circle3 sk-child"></div>';
        $return .=             '<div class="sk-circle4 sk-child"></div>';
        $return .=             '<div class="sk-circle5 sk-child"></div>';
        $return .=             '<div class="sk-circle6 sk-child"></div>';
        $return .=             '<div class="sk-circle7 sk-child"></div>';
        $return .=             '<div class="sk-circle8 sk-child"></div>';
        $return .=             '<div class="sk-circle9 sk-child"></div>';
        $return .=             '<div class="sk-circle10 sk-child"></div>';
        $return .=             '<div class="sk-circle11 sk-child"></div>';
        $return .=             '<div class="sk-circle12 sk-child"></div>';
        $return .=         '</div>';
        $return .=     '</div>';
        $return .=     '<div id="wpv-slider" class="active wpv-none">';
        $return .=         '<img src="" alt="" data-src="' . $this->src . '" data-thumbsrc="" data-no="0">';
        $return .=     '</div>';
        $return .= '</div>';

        return $return;
    }

    /**
     * サムネイル付きのパノラマ画像セットを表示
     *
     * @return string パノラマ画像表示のhtml
     */
    private function getPanoramaSet()
    {
        // 画像id
        $wpv_images = [];
        // 画像名
        $wpv_image_names = [];

        // データ取得
        for ($i = 1; $i <= Cmn::imageCount(); $i++) {
            $tmp_image = wp_strip_all_tags(get_post_meta($this->post_id, '_wpv_image' . $i, true));

            if ((int)$tmp_image < 1) {
                continue;
            }

            $wpv_images[] = $tmp_image;
            $tmp_image_names = wp_strip_all_tags(get_post_meta($this->post_id, '_wpv_image_name' . $i, true));
            $wpv_image_names[] = ($tmp_image_names !== '') ? $tmp_image_names : '　';
        }

        // データが存在するかチェック
        $wpv_images_count = count($wpv_images);
        if ($wpv_images_count < 1) {
            return false;
        }

        // 画像タイプが一つもないかチェック
        $wpv_image_names_count = count(array_values(array_diff($wpv_image_names, ['　'])));

        $return  = '';

        $return .= '<div class="panorama-wrap">';
        $return .=     '<div class="panorama-stage-wrap">';
        $return .=         '<div class="panorama-stage"></div>';
        $return .=         '<div class="panorama-control pause"></div>';
        $return .=         '<div class="panorama-fullscreen" title="最大化">';
        $return .=           '<div class="fullscreen-child1"></div>';
        $return .=           '<div class="fullscreen-child2"></div>';
        $return .=           '<div class="fullscreen-child3"></div>';
        $return .=           '<div class="fullscreen-child4"></div>';
        $return .=         '</div>';
        $return .=         '<div class="panorama-gyro" title="ジャイロ">';
        $return .=           '<div class="gyro-child"></div>';
        $return .=         '</div>';
        $return .=         '<div class="sk-circle panorama-loading">';
        $return .=             '<div class="sk-circle1 sk-child"></div>';
        $return .=             '<div class="sk-circle2 sk-child"></div>';
        $return .=             '<div class="sk-circle3 sk-child"></div>';
        $return .=             '<div class="sk-circle4 sk-child"></div>';
        $return .=             '<div class="sk-circle5 sk-child"></div>';
        $return .=             '<div class="sk-circle6 sk-child"></div>';
        $return .=             '<div class="sk-circle7 sk-child"></div>';
        $return .=             '<div class="sk-circle8 sk-child"></div>';
        $return .=             '<div class="sk-circle9 sk-child"></div>';
        $return .=             '<div class="sk-circle10 sk-child"></div>';
        $return .=             '<div class="sk-circle11 sk-child"></div>';
        $return .=             '<div class="sk-circle12 sk-child"></div>';
        $return .=         '</div>';
        $return .=     '</div>';
        if ($wpv_images_count === 1 && $wpv_image_names[0] !== '　') {
            $return .= '<p>' . $wpv_image_names[0] . '</p>';
        }
        $return .=     '<div id="wpv-slider" class="wpv-slider slider ';
        if ($wpv_images_count === 1) {
            $return .= 'wpv-none';
        }
        $return .=      '">';
        $return .=         '<ul class="slideSet">';
        foreach ($wpv_images as $key => $wpv_image) {
            $return .=         '<li class="';
            if ($key === 0) {
                $return .=     'active ';
            }
            $return .=         'slide">';
            $return .=         '<img src="" alt="" data-src="' . wp_get_attachment_image_src($wpv_image, 'full')[0] . '" data-thumbsrc=' . wp_get_attachment_image_src($wpv_image, 'thumbnail')[0] . ' data-no="' . $key . '" class="wpv-lazyload">';
            if ($wpv_image_names_count > 0) {
                $return .=     '<p>' . $wpv_image_names[$key] . '</p>';
            }
            $return .=         '</li>';
        }
        $return .=         '</ul>';
        $return .=         '<img src="' . Cmn::pluginUrlPath() . 'images/arrow.png" class="slider-prev">';
        $return .=         '<img src="' . Cmn::pluginUrlPath() . 'images/arrow.png" class="slider-next">';
        $return .=     '</div>';
        $return .= '</div>';

        return $return;
    }

    /**
     * 管理画面で設定したパノラマ画像表示に関する設定値を取得する
     * @return string 設定値を反映したスクリプトを返す
     */
    private function getSettingValueScript()
    {
        // 設定値の取得
        $setting_value = Cmn::getSettingValue();

        $return = <<<EOT
        <script>
            if (typeof wpvGl === 'undefined') {
                var wpvGl = {};
            }

            wpvGl.autolotation = {$setting_value['autolotation']};
            wpvGl.autoRotateSpeed = {$setting_value['autolotation_speed']};
            wpvGl.rotateSpeed = {$setting_value['lotation_speed']};
            wpvGl.minDistance = {$setting_value['min_distance']};
            wpvGl.maxDistance = {$setting_value['max_distance']};
            wpvGl.zoomSpeed = {$setting_value['zoom_speed']};
        </script>
EOT;

        return $return;
    }

    /**
     * ショートコードの引数を抽出してセット
     *
     * @param array $atts ショートコードの引数
     */
    private function setShortcodeArgument($atts)
    {
        extract(shortcode_atts(array(
            'post_id' => '',
            'src'     => '',
        ), $atts));

        if (empty($post_id)) {
            $post_id = get_the_ID();
        }

        $this->post_id = $post_id;
        $this->src     = $src;
    }

    /**
     * パノラマ画像表示における条件の検証
     *  ・ショートコードタグのオプションのpost_idが存在するIDか
     *  ・詳細ページまたは固定ページか
     *
     * @return bool
     */
    private function checkCondition()
    {
        // 投稿が存在するか
        if (!$this->post_id) {
            return false;
        }

        // 詳細ページまたは固定ページでない場合は表示しない
        if (!is_single() && !is_page()) {
            return false;
        }

        return true;
    }
}
